fnr: Calculates the False Negative Rate (FNR)

Description Usage Arguments Value Examples

Description

This function takes the predictions of a model, (can be either binary 0 or 1, or continous numeric [0,1]) and calculates the False Negative Rate. Given that predictions need to be binary for the FNR to be calculated you need to pass in a threshold to cut the predictions off. If the predictions are already binary, then pass in .5 FNR = FN / (FN + TP)

Usage

1
fnr(predictions, outcomes, threshold)

Arguments

predictions

list of numerics, predicted values

outcomes

list of numerics, actual values/outcomes

threshold

numeric, value between 0 - 1 to cut predictions that are continous within binary 0s and 1s

Value

numeric, false negative rate

Examples

1
2
fnr(predictions = FakePredictionResults$est.risk.score,
outcomes = FakePredictionResults$true.risk.bin, threshold = .5)

ksboxer/CDIPATools documentation built on June 5, 2019, 8:29 a.m.